**Example 1: 创建文件夹示例**

开发空间-创建文件夹

Input: 

```
tccli wedata CreatePath --cli-unfold-argument  \
    --Name abc \
    --FilePath abc \
    --ProjectId abc
```

Output: 
```
{
    "Response": {
        "Result": true,
        "RequestId": "abc"
    }
}
```

